:py:mod:`test_multi_bed_recon`
==============================

.. py:module:: test_multi_bed_recon

.. autoapi-nested-parse::

   regression test for multi bed recon



Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   test_multi_bed_recon.test_multi_bed_recon
   test_multi_bed_recon.reconstruct_singlebed



Attributes
~~~~~~~~~~

.. autoapisummary::

   test_multi_bed_recon.files_NM


.. py:data:: files_NM
   :value: []

   

.. py:function:: test_multi_bed_recon()


.. py:function:: reconstruct_singlebed(i, projectionss, files_NM, files_CT)


